# Generated by Django 5.2.9 on 2026-02-11 18:25

from django.db import migrations

import netbox_rir_manager.fields


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_rir_manager", "0006_rirticket"),
    ]

    operations = [
        migrations.AlterField(
            model_name="rirconfig",
            name="api_url",
            field=netbox_rir_manager.fields.LenientURLField(blank=True, default=""),
        ),
    ]
