{% extends 'generic/object.html' %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Organization</h5>
            <table class="table table-hover attr-table">
                <tr>
                    <th scope="row">RIR Config</th>
                    <td>{{ object.rir_config|linkify }}</td>
                </tr>
                <tr>
                    <th scope="row">Handle</th>
                    <td>{{ object.handle }}</td>
                </tr>
                <tr>
                    <th scope="row">Name</th>
                    <td>{{ object.name }}</td>
                </tr>
                <tr>
                    <th scope="row">Tenant</th>
                    <td>{{ object.tenant|linkify|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">Last Synced</th>
                    <td>{{ object.last_synced|placeholder }}</td>
                </tr>
            </table>
        </div>
        {% if object.address %}
        <div class="card">
            <h5 class="card-header">Address</h5>
            <table class="table table-hover attr-table">
                <tr>
                    <th scope="row">Street Address</th>
                    <td>{{ object.address.street_address|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">City</th>
                    <td>{{ object.address.city|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">State/Province</th>
                    <td>{{ object.address.state_province|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">Postal Code</th>
                    <td>{{ object.address.postal_code|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">Country</th>
                    <td>{{ object.address.country|placeholder }}</td>
                </tr>
            </table>
        </div>
        {% endif %}
        {% plugin_left_page object %}
    </div>
    <div class="col col-md-6">
        {% include 'inc/panels/tags.html' %}
        {% plugin_right_page object %}
    </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock content %}
