# Generated by Django 5.2.9 on 2026-02-13 03:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_rir_manager", "0011_rirsiteaddress_rirorganization_tenant_rirnetwork_auto_reassign"),
    ]

    operations = [
        migrations.AlterField(
            model_name="rircontact",
            name="last_name",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
    ]
