<button type="submit" name="_sync" formaction="{{ url }}{% if url_params %}?{{ url_params.urlencode }}{% endif %}" class="btn btn-info">
  <i class="mdi mdi-sync" aria-hidden="true"></i> {{ label }}
</button>
