# Generated by Django 5.2.9 on 2026-02-05 03:00

from django.db import migrations

import netbox_rir_manager.fields


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_rir_manager", "0003_add_riruserkey_and_contact_link"),
    ]

    operations = [
        migrations.AlterField(
            model_name="riruserkey",
            name="api_key",
            field=netbox_rir_manager.fields.EncryptedCharField(max_length=512),
        ),
    ]
