{% extends 'generic/object.html' %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Sync Log Entry</h5>
            <table class="table table-hover attr-table">
                <tr>
                    <th scope="row">RIR Config</th>
                    <td>{{ object.rir_config|linkify }}</td>
                </tr>
                <tr>
                    <th scope="row">Operation</th>
                    <td>{{ object.operation }}</td>
                </tr>
                <tr>
                    <th scope="row">Object Type</th>
                    <td>{{ object.object_type }}</td>
                </tr>
                <tr>
                    <th scope="row">Object Handle</th>
                    <td>{{ object.object_handle }}</td>
                </tr>
                <tr>
                    <th scope="row">Status</th>
                    <td>{{ object.status }}</td>
                </tr>
                <tr>
                    <th scope="row">Message</th>
                    <td>{{ object.message|placeholder }}</td>
                </tr>
                <tr>
                    <th scope="row">Created</th>
                    <td>{{ object.created }}</td>
                </tr>
            </table>
        </div>
        {% plugin_left_page object %}
    </div>
    <div class="col col-md-6">
        {% include 'inc/panels/tags.html' %}
        {% plugin_right_page object %}
    </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock content %}
